#
# spec file for package perl-Crypt-OpenSSL-Random
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Crypt-OpenSSL-Random
Name:           perl-Crypt-OpenSSL-Random
Version:        0.170.0
Release:        1.3
# 0.17 -> normalize -> 0.170.0
%define cpan_version 0.17
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        OpenSSL/LibreSSL pseudo-random number generator access
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RU/RURBAN/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Crypt::OpenSSL::Guess) >= 0.11
BuildRequires:  perl(Test::Pod) >= 1.22
Provides:       perl(Crypt::OpenSSL::Random) = %{version}
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  openssl-devel
# MANUAL END

%description
'Crypt::OpenSSL::Random' provides the ability to seed and query the
*OpenSSL* and *LibreSSL* library's pseudo-random number generators.

Note: On *LibreSSL* 'random_egd()' is not defined.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc appveyor.cmd Changes README
%license LICENSE

%changelog
* Sun Jun 23 2024 Tina Müller <tina.mueller@suse.com>
- updated to 0.170.0 (0.17)
  see /usr/share/doc/packages/perl-Crypt-OpenSSL-Random/Changes
  0.17  2024-06-13 rurban
  - fix older aix with missing -lz dependencies (timlegge PR #16)
  - minor ci fixes
* Sun Apr 14 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.16
  see /usr/share/doc/packages/perl-Crypt-OpenSSL-Random/Changes
  0.16  2024-04-13 rurban
  - add github actions, travis and appveyor.
  - Many patches by Takumi Akiyama.
  - Fix broken github image for strawberry perl
    by stripping its PATH. their new mingw is incompatible to their
    old strawberry 5.32
  - minor documentation fixes.
* Sun Oct  7 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix autogenerated changes to build again
* Mon Apr 23 2018 coolo@suse.com
- updated to 0.15
  see /usr/share/doc/packages/perl-Crypt-OpenSSL-Random/Changes
  0.15  2018-04-22 rurban
  - fix mingw hints for pkg-config support (akiym, PR #7)
* Wed Apr 18 2018 coolo@suse.com
- updated to 0.14
  see /usr/share/doc/packages/perl-Crypt-OpenSSL-Random/Changes
  0.14  2018-04-17 rurban
  - add library paths to LIBS from Crypt::OpenSSL::Guess (akiym, PR #6)
* Sun Apr 15 2018 coolo@suse.com
- updated to 0.13
  see /usr/share/doc/packages/perl-Crypt-OpenSSL-Random/Changes
  0.13  2018-04-14 rurban
  - move Crypt::OpenSSL::Guess to configure dependency. (grinnz, PR #4)
* Sat Apr 14 2018 coolo@suse.com
- updated to 0.12
  see /usr/share/doc/packages/perl-Crypt-OpenSSL-Random/Changes
  0.12  2018-04-13 rurban
  - use Crypt::OpenSSL::Guess to resolve OpenSSL include path,
    fixes MacOS's homebrew OpenSSL installation problem. (akiym, PR #3)
* Wed Aug 23 2017 vcizek@suse.com
- update to 0.11
  - add libressl support, unsupported random_egd() with libressl
  - fixes testsuite failure with OpenSSL 1.1 (bsc#1055236)
* Sat Feb  7 2015 coolo@suse.com
- updated to 0.10
  - fix LIBS argument, fatal on Windows. thanks to kmx
  0.09  2015-02-04 rurban
  - add missing hints/MSWin32.pl (kmx, RT #56455)
  - add a couple of distro tests
  - fix gcov target
  0.08  2015-02-03 rurban
  - remove Devel::CheckLib which does not work for 2 required libs
  - replace DynaLoader by XSLoader
  0.07  2015-02-03 rurban
  - Bump version to publish an official release
  0.06  rurban
  - Typo in doc (dsteinbrunner)
  0.05  2013-04-02 14:31:30 rurban
  - Add inc/Devel/CheckLib, improve POD, add README and some helper targets
  - Better diagnostics when the openssl libraries are not found
  - Support INCDIR= and LIBDIR= arguments to Makefile.PL
  - Add MSWin32 hints to find the openssl libraries
  - Autocreate README
  - Fix some -Wpointer-sign warnings
  - Remove wrong Crypt::OpenSSL::RSA package names in docs and errmsg
* Wed Jun  6 2012 cfarrell@suse.com
- license update: GPL-1.0+ or Artistic-1.0
  SPDX format
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Mon Nov 29 2010 coolo@novell.com
- recreated by cpanspec 1.78.02
* Sun Nov 28 2010 coolo@novell.com
- remove .packlist file
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Tue Jan 20 2009 varkoly@suse.de
- Initial version of perl-Crypt-OpenSSL-Random
